@@ -177,13 +177,9 @@ class BackupJob {
             $command = "cd " . escapeshellarg(dirname($userDir)) . " && tar -cf " . escapeshellarg($tempFile) . " --use-compress-program='gzip -6' " . escapeshellarg($userName . "/" . $domainName);
         }
 
-        // Execute with timeout wrapper (10 minutes for tar operations)
-        $timeoutCommand = "timeout 600 " . $command;
-        exec($timeoutCommand, $output, $returnCode);
+        exec($command, $output, $returnCode);
 
-        if ($returnCode === 124) {
-            throw new Exception("Site archive creation timed out after 10 minutes");
-        } elseif ($returnCode !== 0) {
+        if ($returnCode !== 0) {
             throw new Exception("Failed to create site archive: " . implode("\n", $output));
         }
         
@@ -210,13 +206,9 @@ class BackupJob {
             $command = "cd " . escapeshellarg(dirname($userDir)) . " && tar -czf " . escapeshellarg($tempFile) . " --use-compress-program='gzip -6' " . escapeshellarg($userName . "/userfiles") . " 2>&1";
         }
 
-        // Execute with timeout wrapper (10 minutes for tar/zip operations)
-        $timeoutCommand = "timeout 600 " . $command;
-        exec($timeoutCommand, $output, $returnCode);
+        exec($command, $output, $returnCode);
 
-        if ($returnCode === 124) {
-            throw new Exception("Userfiles archive creation timed out after 10 minutes");
-        } elseif ($returnCode !== 0) {
+        if ($returnCode !== 0) {
             throw new Exception("Failed to create userfiles archive: " . implode("\n", $output));
         }
         
@@ -237,13 +229,9 @@ class BackupJob {
         // Create zip archive
         $command = "cd " . escapeshellarg(dirname($userDir)) . " && zip -r " . escapeshellarg($tempFile) . " " . escapeshellarg($userName . "/userfiles") . " 2>&1";
 
-        // Execute with timeout wrapper (10 minutes for zip operations)
-        $timeoutCommand = "timeout 600 " . $command;
-        exec($timeoutCommand, $output, $returnCode);
+        exec($command, $output, $returnCode);
 
-        if ($returnCode === 124) {
-            throw new Exception("Userfiles archive creation timed out after 10 minutes");
-        } elseif ($returnCode !== 0) {
+        if ($returnCode !== 0) {
             throw new Exception("Failed to create userfiles archive: " . implode("\n", $output));
         }
         
@@ -292,17 +280,9 @@ class BackupJob {
                   " --add-drop-database --create-options --complete-insert" .
                   " --databases " . escapeshellarg($database) . 
                   " > " . escapeshellarg($tempSqlFile) . " 2>&1";
-        // Execute with timeout wrapper (10 minutes for database dumps)
-        $timeoutCommand = "timeout 600 " . $command;
-        exec($timeoutCommand, $output, $returnCode);
+        exec($command, $output, $returnCode);
 
-        if ($returnCode === 124) {
-            // Clean up temp file
-            if (file_exists($tempSqlFile)) {
-                unlink($tempSqlFile);
-            }
-            throw new Exception("Database dump timed out after 10 minutes");
-        } elseif ($returnCode !== 0) {
+        if ($returnCode !== 0) {
             // Clean up temp file
             if (file_exists($tempSqlFile)) {
                 unlink($tempSqlFile);
@@ -323,17 +303,13 @@ class BackupJob {
             $gzipCommand = "gzip -6 -c " . escapeshellarg($tempSqlFile) . " > " . escapeshellarg($tempFile);
         }
 
-        // Execute with timeout wrapper (10 minutes for compression)
-        $timeoutGzipCommand = "timeout 600 " . $gzipCommand;
-        exec($timeoutGzipCommand, $gzipOutput, $gzipReturn);
+        exec($gzipCommand, $gzipOutput, $gzipReturn);
 
         // Clean up temp SQL file
         if (file_exists($tempSqlFile)) {
             unlink($tempSqlFile);
         }
-        if ($gzipReturn === 124) {
-            throw new Exception("SQL dump compression timed out after 10 minutes");
-        } elseif ($gzipReturn !== 0) {
+        if ($gzipReturn !== 0) {
             throw new Exception("Failed to compress database dump: " . implode("\n", $gzipOutput));
         }
         
@@ -392,13 +368,9 @@ class BackupJob {
             $filesArg = implode(' ', array_map('escapeshellarg', $filesToArchive));
             $command = "cd " . escapeshellarg($tempWorkDir) . " && tar -czf " . escapeshellarg($tempFile) . " " . $filesArg;
 
-            // Execute with timeout wrapper (10 minutes for WordPress archive)
-            $timeoutCommand = "timeout 600 " . $command;
-            exec($timeoutCommand, $output, $returnCode);
+            exec($command, $output, $returnCode);
 
-            if ($returnCode === 124) {
-                throw new Exception("WordPress archive creation timed out after 10 minutes");
-            } elseif ($returnCode !== 0) {
+            if ($returnCode !== 0) {
                 throw new Exception("Failed to create WordPress archive: " . implode("\n", $output));
             }
 
@@ -430,13 +402,9 @@ class BackupJob {
             $command = "cd " . escapeshellarg(dirname($userDir)) . " && tar -czf " . escapeshellarg($tempFile) . " " . escapeshellarg($userName . "/" . $domainName);
         }
 
-        // Execute with timeout wrapper (10 minutes for tar operations)
-        $timeoutCommand = "timeout 600 " . $command;
-        exec($timeoutCommand, $output, $returnCode);
+        exec($command, $output, $returnCode);
 
-        if ($returnCode === 124) {
-            throw new Exception("Site archive creation timed out after 10 minutes");
-        } elseif ($returnCode !== 0) {
+        if ($returnCode !== 0) {
             throw new Exception("Failed to create site archive: " . implode("\n", $output));
         }
 
