@@ -1168,18 +1168,49 @@ function runSchedulerNow() {
 }
 
 function showAlert(message, type) {
+    // Create or get the floating alert container
+    let alertContainer = document.getElementById('floating-alert-container');
+    if (!alertContainer) {
+        alertContainer = document.createElement('div');
+        alertContainer.id = 'floating-alert-container';
+        alertContainer.style.cssText = `
+            position: fixed;
+            top: 80px;
+            left: 20px;
+            right: 20px;
+            max-width: 500px;
+            z-index: 9999;
+            pointer-events: none;
+        `;
+        document.body.appendChild(alertContainer);
+    }
+
     const alertDiv = document.createElement('div');
     alertDiv.className = `alert alert-${type} alert-dismissible fade show`;
+    alertDiv.style.cssText = `
+        pointer-events: auto;
+        margin-bottom: 10px;
+        box-shadow: 0 4px 12px rgba(0, 0, 0, 0.15);
+        animation: slideInLeft 0.3s ease-out;
+    `;
     alertDiv.innerHTML = `
         ${message}
         <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
     `;
-    
-    document.querySelector('.container-fluid').insertBefore(alertDiv, document.querySelector('.container-fluid').firstChild);
-    
+
+    alertContainer.appendChild(alertDiv);
+
+    // Auto-dismiss after 15 seconds
     setTimeout(() => {
-        alertDiv.remove();
-    }, 5000);
+        if (alertDiv && alertDiv.parentNode) {
+            alertDiv.classList.add('fade');
+            setTimeout(() => {
+                if (alertDiv.parentNode) {
+                    alertDiv.remove();
+                }
+            }, 150);
+        }
+    }, 15000);
 }
 
 // Convert UTC times to local timezone
@@ -1533,6 +1564,29 @@ document.getElementById('targetGlobal').addEventListener('change', function() {
 <?php endif; ?>
 </script>
 
+<style>
+/* Animation for alerts sliding in */
+@keyframes slideInLeft {
+    from {
+        transform: translateX(-100%);
+        opacity: 0;
+    }
+    to {
+        transform: translateX(0);
+        opacity: 1;
+    }
+}
+
+/* Responsive adjustments for alerts */
+@media (max-width: 768px) {
+    #floating-alert-container {
+        left: 10px !important;
+        right: 10px !important;
+        max-width: none !important;
+    }
+}
+</style>
+
 <?php
 function formatBytes($bytes, $precision = 2) {
     if ($bytes <= 0) {
